@@ -6,23 +6,27 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTVIEWER_H
-#define AKONADI_CONTACTVIEWER_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
-#include <itemmonitor.h>
+#include <Akonadi/ItemMonitor>
 
 #include <QWidget>
 
-namespace KContacts {
+#include <memory>
+
+namespace KContacts
+{
 class Address;
 class Addressee;
 class PhoneNumber;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class AbstractContactFormatter;
+class ContactViewerPrivate;
 
 /**
  * @short A viewer component for contacts in Akonadi.
@@ -177,8 +181,7 @@ private:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<ContactViewerPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void slotUrlClicked(const QUrl &))
     Q_PRIVATE_SLOT(d, void slotParentCollectionFetched(KJob *))
@@ -186,4 +189,3 @@ private:
 };
 }
 
-#endif
