@@ -7,16 +7,19 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_EMAILADDRESSSELECTIONDIALOG_H
-#define AKONADI_EMAILADDRESSSELECTIONDIALOG_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include "abstractemailaddressselectiondialog.h"
 #include "emailaddressselectionwidget.h"
 
+#include <memory>
+
 namespace Akonadi
 {
+class EmailAddressSelectionDialogPrivate;
+
 /**
  * @short A dialog to select email addresses from Akonadi.
  *
@@ -79,10 +82,8 @@ public:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<EmailAddressSelectionDialogPrivate> const d;
     //@endcond
 };
 }
 
-#endif
